/**************************\
  Basic Modal Styles
\**************************/

.modal {
  font-family: -apple-system,BlinkMacSystemFont,avenir next,avenir,helvetica neue,helvetica,ubuntu,roboto,noto,segoe ui,arial,sans-serif;
}

.modal__overlay {
  position: fixed;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  background: rgba(0,0,0,0.6);
  display: flex;
  justify-content: center;
  align-items: center;
  z-index: 9999;
}

.modal__container {
  background-color: #fff;
  padding: 30px;
  max-width: 100vw;
  border-radius: 4px;
  box-sizing: border-box;
}

.modal__header {
  display: flex;
  justify-content: space-between;
  align-items: center;
}

.modal__title {
  margin-top: 0;
  margin-bottom: 0;
  font-weight: 600;
  font-size: 1.25rem;
  line-height: 1.25;
  color: var(--primary);
  box-sizing: border-box;
}

.modal__close {
  background: transparent;
  border: 0;
}

.modal__header .modal__close:before { content: "\2715"; }

.modal main {
  padding: 0 10px;
  box-sizing: border-box;
  width:832px;
  max-width: 100%;
  margin-top: 2rem;
  margin-bottom: 2rem;
  line-height: 1.5;
  height: 50vh;
  display: flex;
  flex-wrap: wrap;
}
.modal__content {
  color: rgba(0,0,0,.8);
  overflow-y: scroll;
  box-sizing: border-box;
  align-content: flex-start;
}
.modal__footer {
  padding: 0 10px;
  text-align: right;
}
.modal__item {
  background-color:white;
  background-size:100% auto;
  background-repeat:no-repeat;
  background-position:center;
  width:200px;
  height:200px;
  box-sizing:border-box;
}
.modal__item_active {
  border: 4px solid var(--orange);
}
.modal__tabs {
  margin: 1rem 0 0 !important;
  padding: 0 !important;
  list-style-type: none;
  border-bottom: 1px solid lightgrey;
}
.modal__tabs li {
  display: inline-block;
  margin-bottom: -1px;
  border: 1px solid white;
  border-bottom-color: lightgrey;
}
.modal__tabs li a {
  display: inline-block;
  padding: 0.5rem 1rem;
  background: white;
}
.modal__tabs .modal__tabs__item_active {
  border-color: lightgrey;
  border-bottom-color: white;
}

.modal__btn {
  font-size: .875rem;
  padding-left: 1rem;
  padding-right: 1rem;
  padding-top: .5rem;
  padding-bottom: .5rem;
  background-color: #e6e6e6;
  color: rgba(0,0,0,.8);
  border-radius: .25rem;
  border-style: none;
  border-width: 0;
  cursor: pointer;
  -webkit-appearance: button;
  text-transform: none;
  overflow: visible;
  line-height: 1.15;
  margin: 0;
  will-change: transform;
  -moz-osx-font-smoothing: grayscale;
  -webkit-backface-visibility: hidden;
  backface-visibility: hidden;
  -webkit-transform: translateZ(0);
  transform: translateZ(0);
  transition: -webkit-transform .25s ease-out;
  transition: transform .25s ease-out;
  transition: transform .25s ease-out,-webkit-transform .25s ease-out;
}

.modal__btn_sm {
  font-size: .7rem;
  padding: 0.25rem 1rem;
}

//.modal__btn:focus, .modal__btn:hover {
//  -webkit-transform: scale(1.05);
//  transform: scale(1.05);
//}

.modal__btn-primary {
  background-color: var(--primary);
  color: #fff;
}



/**************************\
  Demo Animation Style
\**************************/
@keyframes mmfadeIn {
    from { opacity: 0; }
      to { opacity: 1; }
}

@keyframes mmfadeOut {
    from { opacity: 1; }
      to { opacity: 0; }
}

@keyframes mmslideIn {
  from { transform: translateY(15%); }
    to { transform: translateY(0); }
}

@keyframes mmslideOut {
    from { transform: translateY(0); }
    to { transform: translateY(-10%); }
}

.micromodal-slide {
  display: none;
}

.micromodal-slide.is-open {
  display: block;
}

.micromodal-slide[aria-hidden="false"] .modal__overlay {
  animation: mmfadeIn .3s cubic-bezier(0.0, 0.0, 0.2, 1);
}

.micromodal-slide[aria-hidden="false"] .modal__container {
  animation: mmslideIn .3s cubic-bezier(0, 0, .2, 1);
}

.micromodal-slide[aria-hidden="true"] .modal__overlay {
  animation: mmfadeOut .3s cubic-bezier(0.0, 0.0, 0.2, 1);
}

.micromodal-slide[aria-hidden="true"] .modal__container {
  animation: mmslideOut .3s cubic-bezier(0, 0, .2, 1);
}

.micromodal-slide .modal__container,
.micromodal-slide .modal__overlay {
  will-change: transform;
}
